@@ -1,7 +1,7 @@
 package App::HasPrereqs;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -114,7 +114,7 @@ App::HasPrereqs - Check whether your Perl installation has prerequisites in dist
 
 =head1 VERSION
 
-This document describes version 0.07 of App::HasPrereqs (from Perl distribution App-HasPrereqs), released on 2015-08-17.
+This document describes version 0.08 of App::HasPrereqs (from Perl distribution App-HasPrereqs), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -125,7 +125,7 @@ This document describes version 0.07 of App::HasPrereqs (from Perl distribution
 
 =head2 has_prereqs(%args) -> [status, msg, result, meta]
 
-{en_US Check whether your Perl installation has prerequisites in dist.ini}.
+Check whether your Perl installation has prerequisites in dist.ini.
 
 Arguments ('*' denotes required arguments):
 
@@ -133,7 +133,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<library> => I<array[str]>
 
-{en_US Add directory to @INC}.
+Add directory to @INC.
 
 =back
 
